psychopy_ext.models.HMAX.get_VTU — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.models.HMAX.get_VTU

`HMAX.` `get_VTU`(C2resp, tuningWidth=0.1)

  Calculate response of view-tuned units

  Parameters
    c2RespSpec: numpy.array
      C2 responses to the stimuli
    tuningWidth: float
      How sharply VTUs should be tuned; lower values are shaper tuning (default: .1)
  Returns
    output: np.array
      An array where each column represents view-tuned units responses to a particular image (stimulus)